library(fields);
#data= data in the TESS format. Can contain coordinates only, and extraCol extra columns.
#estimates= estimation of admixture proportions in the CLUMPP format
#twoRows (boolean)= Are the individual coordinates stored in two lines per individual (true, default)?
#extraCol= number of extra columns in the file "data" (extra columns must be the first columns)
#onePlot= one window for all interpolations (true, default).
#drawAxes= draw the plot axes
#ncols= number of colors to use in palette
#sc= scaling parameter for the kriging function
#extrapol= should we predict outside data range
krigAdmixProportions <- function(data,estimates,twoRows=TRUE,extraCol=0,onePlot=TRUE,drawAxes=FALSE,ncols=20,sc=0,extrapol=T)
{
   NbInd <- 0;
   if (twoRows)
   {
      #two rows per individual
      NbInd <- nrow(data)/2;
      coord <- data[(1:(2*NbInd)) %% 2 == 0,(1+extraCol):(2+extraCol)];
   }
   else
   {
     #one row per individual
     NbInd <- nrow(data);
     coord <- data[,(1+extraCol):(2+extraCol)];
   }
   
   Kmax <- ncol(estimates) - 2;
   toKrig <- estimates[,2:(Kmax+1)]; #discard first (individual label) and last (1) columns
   
   # color
   #colrp <- colorRampPalette(c("white","red","darkred"))(20)
   colrp <- heat.colors(ncols);
   if (onePlot)
   {
     par(mfrow=c(1,Kmax));
   }
   if (sc == 0)
   {
   	sc <- mean(mean(coord)); #scale parameter
   }
   for (k in 1:Kmax)
   {
     if (!onePlot)
     {
       X11();
     }
     fit<- Krig(coord, toKrig[,k], theta= sc, m = 1, Distance="rdist.earth",na.rm=TRUE);
     surface(fit, type ="I", col = colrp, xlab ="", ylab="", las = 1, main = paste("cluster",k), extrap = extrapol,axes=drawAxes);
     points(coord, pch = 19, cex = .5);
   }
}
